@@ -2,7 +2,8 @@ package FBP::Demo::Main;
 
 ## no critic
 
-use 5.008;
+use 5.008005;
+use utf8;
 use strict;
 use warnings;
 use Wx 0.98 ':everything';
@@ -26,7 +27,19 @@ sub new {
 	$self->{m_staticText1} = Wx::StaticText->new(
 		$self,
 		-1,
-		"This is the FBP::Perl demonstration project.\n\nIt shows a complete working standalone application skeleton as produced by FBP::Perl.",
+		"This is the FBP::Perl demonstration project.\n\nIt shows a complete working standalone application skeleton as produced by FBP::Perl.\n\nThis sample also demonstrates Unicode text.",
+	);
+
+	$self->{m_staticText2} = Wx::StaticText->new(
+		$self,
+		-1,
+		"Cet exemple d\x{e9}montre \x{e9}galement le texte Unicode.",
+	);
+
+	$self->{m_staticText3} = Wx::StaticText->new(
+		$self,
+		-1,
+		"此示例还演示Unicode文本。",
 	);
 
 	$self->{m_staticline1} = Wx::StaticLine->new(
@@ -55,6 +68,8 @@ sub new {
 
 	my $bSizer1 = Wx::BoxSizer->new(wxVERTICAL);
 	$bSizer1->Add( $self->{m_staticText1}, 0, wxALL, 5 );
+	$bSizer1->Add( $self->{m_staticText2}, 0, wxALL, 5 );
+	$bSizer1->Add( $self->{m_staticText3}, 0, wxALL, 5 );
 	$bSizer1->Add( $self->{m_staticline1}, 0, wxEXPAND | wxALL, 5 );
 	$bSizer1->Add( $self->{simple_button}, 0, wxALL, 5 );
 
